@@ -21,8 +21,8 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#ifndef __EOG_METADATA_SIDEBAR_H__
-#define __EOG_METADATA_SIDEBAR_H_
+#ifndef EOG_METADATA_SIDEBAR_H
+#define EOG_METADATA_SIDEBAR_H
 
 #include <glib-object.h>
 #include <gtk/gtk.h>
@@ -60,4 +60,4 @@ GtkWidget* eog_metadata_sidebar_new (EogWindow *window);
 
 G_END_DECLS
 
-#endif /* __EOG_METADATA_SIDEBAR_H__ */
+#endif /* EOG_METADATA_SIDEBAR_H */
